irl\_benchmark.rl package
=========================

Subpackages
-----------

.. toctree::

    irl_benchmark.rl.algorithms

Module contents
---------------

.. automodule:: irl_benchmark.rl
    :members:
    :undoc-members:
    :show-inheritance:
